==> gatherer-2.99.0.0372.zip: Gatherer/GatherStrings.lua <==
﻿--[[
	WARNING: This is a generated file.
	If you wish to perform or update localizations, please go to our Localizer website at:
	http://www.norganna.org/localizer/index.php

	AddOn: Gatherer
	Revision: $Id: GatherStrings.lua 372 2006-12-31 06:32:43Z esamynn $
	Version: 2.99.0.0372 (eagle)

	License:
		This program is free software; you can redistribute it and/or
		modify it under the terms of the GNU General Public License
		as published by the Free Software Foundation; either version 2
		of the License, or (at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program(see GPL.txt); if not, write to the Free Software
		Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

	Note:
		This AddOn's source code is specifically designed to work with
		World of Warcraft's interpreted AddOn system.
		You have an implicit licence to use this AddOn with these facilities
		since that is it's designated purpose as per:
		http://www.fsf.org/licensing/licenses/gpl-faq.html#InterpreterIncompat
]]

GathererLocalizations = {

	daDK = {


		-- Section: Node Category Names
		ORE_ADAMANTITE	= "Adamantit";
		ORE_BLOODSTONE	= "Blodsten";
		ORE_COPPER	= "Kobber";
		ORE_DARKIRON	= "mørk jern";
		ORE_FELIRON	= "Demonisk jern";
		ORE_GOLD	= "guld";
		ORE_INCENDICITE	= "Incendicite";
		ORE_INDURIUM	= "Indurium";
		ORE_IRON	= "jern";
		ORE_KHORIUM	= "Khorium";
		ORE_MITHRIL	= "mithril";
		ORE_OBSIDIAN	= "Obsidian";
		ORE_RADAMANTITE	= "Beriget Adamantit";
		ORE_RTHORIUM	= "Beriget Thorium";
		ORE_SILVER	= "sølv";
		ORE_THORIUM	= "thorium";
		ORE_TIN	= "tin";
		ORE_TRUESILVER	= "Ædelsølv";
		TREASURE_BARREL	= "Tønder";
		TREASURE_BLOODPETAL	= "Blodblomst skud";
		TREASURE_BOX	= "Kasser";
		TREASURE_CASK	= "Fustage";
		TREASURE_CHEST	= "Skatte kiste";
		TREASURE_CLAM	= "Kæmpe muslinger";
		TREASURE_CRATE	= "Kister";
		TREASURE_FOOTLOCKER	= "Skibskiste";
		TREASURE_NIGHTDRAGON	= "Natte Dragens ånde";
		TREASURE_POWERCRYST	= "Kraft krystal";
		TREASURE_SHELLFISHTRAP	= "Krebsdyr fælde";
		TREASURE_SONGFLOWER	= "Sangblomster";
		TREASURE_UNGOROSOIL	= "Un'Goro muld";
		TREASURE_WHIPPERROOT	= "Piskerod knold";
		TREASURE_WINDBLOSSOM	= "Vindblomst bær";


		-- Section: Trade Skill Names
		TRADE_HERBALISM	= "Urter";
		TRADE_MINING	= "Mineraler";

	};

	deDE = {


		-- Section: Node Category Names
		ORE_ADAMANTITE	= "Adamantit";
		ORE_BLOODSTONE	= "Geringes Blutstein";
		ORE_COPPER	= "Kupfer";
		ORE_DARKIRON	= "Dunkeleisen";
		ORE_FELIRON	= "Teufelseisen";
		ORE_GOLD	= "Gold";
		ORE_INCENDICITE	= "Pyrophor";
		ORE_INDURIUM	= "Indurium";
		ORE_IRON	= "Eisen";
		ORE_KHORIUM	= "Khorium";
		ORE_MITHRIL	= "Mithril";
		ORE_OBSIDIAN	= "Obsidian";
		ORE_RADAMANTITE	= "Reiches Adamantit";
		ORE_RTHORIUM	= "Reiches Thorium";
		ORE_SILVER	= "Silber";
		ORE_THORIUM	= "Thorium";
		ORE_TIN	= "Zinn";
		ORE_TRUESILVER	= "Echtsilber";
		TREASURE_BARREL	= "Fass";
		TREASURE_BLOODPETAL	= "Blutblütensprösslinge";
		TREASURE_BOX	= "Kiste";
		TREASURE_CASK	= "Fässlein";
		TREASURE_CHEST	= "Schatztruhe";
		TREASURE_CLAM	= "Riesenmuschel";
		TREASURE_CRATE	= "Kiste";
		TREASURE_FOOTLOCKER	= "Schließkiste";
		TREASURE_NIGHTDRAGON	= "Nachtdrachenodem";
		TREASURE_POWERCRYST	= "Machtkristall";
		TREASURE_SHELLFISHTRAP	= "Schalentierfalle";
		TREASURE_SONGFLOWER	= "Liedblume";
		TREASURE_UNGOROSOIL	= "Erde von Un'Goro";
		TREASURE_WHIPPERROOT	= "Peitscherwurzelknollen";
		TREASURE_WINDBLOSSOM	= "Windblütenbeeren";


		-- Section: Trade Skill Names
		TRADE_HERBALISM	= "Kräuterkunde";
		TRADE_MINING	= "Bergbau";

	};

	enUS = {


		-- Section: Node Category Names
		ORE_ADAMANTITE	= "Adamantite";
		ORE_BLOODSTONE	= "Lesser Bloodstone";
		ORE_COPPER	= "Copper";
		ORE_DARKIRON	= "Dark Iron";
		ORE_FELIRON	= "Fel Iron";
		ORE_GOLD	= "Gold";
		ORE_INCENDICITE	= "Incendicite";
		ORE_INDURIUM	= "Indurium";
		ORE_IRON	= "Iron";
		ORE_KHORIUM	= "Khorium";
		ORE_MITHRIL	= "Mithril";
		ORE_OBSIDIAN	= "Obsidian";
		ORE_RADAMANTITE	= "Rich Adamantite";
		ORE_RTHORIUM	= "Rich Thorium";
		ORE_SILVER	= "Silver";
		ORE_THORIUM	= "Thorium";
		ORE_TIN	= "Tin";
		ORE_TRUESILVER	= "Truesilver";
		TREASURE_BARREL	= "Barrels";
		TREASURE_BLOODPETAL	= "Bloodpetal Sprouts";
		TREASURE_BOX	= "Boxes";
		TREASURE_CASK	= "Casks";
		TREASURE_CHEST	= "Tresure Chests";
		TREASURE_CLAM	= "Giant Clams";
		TREASURE_CRATE	= "Crates";
		TREASURE_FOOTLOCKER	= "Footlockers";
		TREASURE_NIGHTDRAGON	= "Night Dragon's Breath";
		TREASURE_POWERCRYST	= "Power Crystals";
		TREASURE_SHELLFISHTRAP	= "Shellfish Traps";
		TREASURE_SONGFLOWER	= "Songflowers";
		TREASURE_UNGOROSOIL	= "Un'Goro Soil";
		TREASURE_WHIPPERROOT	= "Whipper Root Tubers";
		TREASURE_WINDBLOSSOM	= "Windblossom Berries";


		-- Section: Trade Skill Names
		TRADE_HERBALISM	= "Herbalism";
		TRADE_MINING	= "Mining";

	};

	koKR = {


		-- Section: Node Category Names
		ORE_ADAMANTITE	= "아다만타이트";
		ORE_BLOODSTONE	= "저급 혈석";
		ORE_COPPER	= "구리";
		ORE_DARKIRON	= "검은 무쇠";
		ORE_GOLD	= "금";
		ORE_INCENDICITE	= "발연";
		ORE_INDURIUM	= "인듀리움";
		ORE_IRON	= "철";
		ORE_KHORIUM	= "코륨";
		ORE_MITHRIL	= "미스릴";
		ORE_OBSIDIAN	= "흑요석";
		ORE_RADAMANTITE	= "풍부한 아다만타이트";
		ORE_RTHORIUM	= "풍부한 토륨";
		ORE_SILVER	= "은";
		ORE_THORIUM	= "토륨";
		ORE_TIN	= "주석";
		ORE_TRUESILVER	= "진은";
		TREASURE_BLOODPETAL	= "붉은꽃잎 씨앗";
		TREASURE_CLAM	= "커다란 조개";
		TREASURE_FOOTLOCKER	= "사물함";
		TREASURE_NIGHTDRAGON	= "어둠용의 숨결";
		TREASURE_POWERCRYST	= "마력의 수정";
		TREASURE_SONGFLOWER	= "노래꽃";
		TREASURE_UNGOROSOIL	= "운고로 토양";
		TREASURE_WHIPPERROOT	= "채찍뿌리 줄기";
		TREASURE_WINDBLOSSOM	= "바람꽃 열매";


		-- Section: Trade Skill Names
		TRADE_HERBALISM	= "약초채집";
		TRADE_MINING	= "채광";

	};

	esES = {


		-- Section: Node Category Names
		ORE_COPPER	= "cobre";
		ORE_DARKIRON	= "hierro negro";
		ORE_GOLD	= "oro";
		ORE_IRON	= "hierro";
		ORE_MITHRIL	= "mitril";
		ORE_SILVER	= "plata";
		ORE_THORIUM	= "torio";
		ORE_TIN	= "estaño";
		ORE_TRUESILVER	= "veraplata";

	};

	frFR = {


		-- Section: Node Category Names
		ORE_COPPER	= "cuivre";
		ORE_DARKIRON	= "sombrefer";
		ORE_GOLD	= "or";
		ORE_IRON	= "fer";
		ORE_MITHRIL	= "mithril";
		ORE_SILVER	= "argent";
		ORE_THORIUM	= "thorium";
		ORE_TIN	= "étain";
		ORE_TRUESILVER	= "vrai-argent";


		-- Section: Trade Skill Names
		TRADE_HERBALISM	= "Herboristerie";
		TRADE_MINING	= "Minage";

	};

	itIT = {


		-- Section: Node Category Names
		ORE_COPPER	= "rame";
		ORE_DARKIRON	= "ferro oscuro";
		ORE_GOLD	= "oro";
		ORE_IRON	= "ferro";
		ORE_MITHRIL	= "mithril";
		ORE_SILVER	= "argento";
		ORE_THORIUM	= "thorium";
		ORE_TIN	= "stagno";
		ORE_TRUESILVER	= "argento vero";

	};

	nlNL = {


		-- Section: Node Category Names
		ORE_COPPER	= "koper";
		ORE_DARKIRON	= "duister ijzer";
		ORE_GOLD	= "goud";
		ORE_IRON	= "ijzer";
		ORE_MITHRIL	= "mithril";
		ORE_SILVER	= "zilver";
		ORE_THORIUM	= "thorium";
		ORE_TIN	= "tin";
		ORE_TRUESILVER	= "waarzilver";

	};

	ruRU = {


		-- Section: Node Category Names
		ORE_COPPER	= "Медь";
		ORE_DARKIRON	= "Темное железо";
		ORE_GOLD	= "Золото";
		ORE_IRON	= "Железо";
		ORE_MITHRIL	= "Мифрил";
		ORE_SILVER	= "Серебро";
		ORE_THORIUM	= "Ториум";
		ORE_TIN	= "Бронза";
		ORE_TRUESILVER	= "Истинное Серебро";

	};

	zhCN = {


		-- Section: Node Category Names
		ORE_COPPER	= "铜";
		ORE_DARKIRON	= "黑铁";
		ORE_GOLD	= "金";
		ORE_IRON	= "铁";
		ORE_MITHRIL	= "秘银";
		ORE_SILVER	= "银";
		ORE_THORIUM	= "瑟银";
		ORE_TIN	= "锡";
		ORE_TRUESILVER	= "真银";

	};

	zhTW = {


		-- Section: Node Category Names
		ORE_COPPER	= "銅礦";
		ORE_DARKIRON	= "黑鐵礦";
		ORE_GOLD	= "金礦";
		ORE_IRON	= "鐵礦";
		ORE_MITHRIL	= "秘銀";
		ORE_SILVER	= "銀礦";
		ORE_THORIUM	= "瑟銀";
		ORE_TIN	= "錫礦";
		ORE_TRUESILVER	= "真銀礦";

	};
}

==> gatherer-2.99.0.0394.zip: Gatherer/GatherStrings.lua <==
﻿--[[
	WARNING: This is a generated file.
	If you wish to perform or update localizations, please go to our Localizer website at:
	http://www.norganna.org/localizer/index.php

	AddOn: Gatherer
	Revision: $Id: GatherStrings.lua 384 2007-01-03 19:14:00Z esamynn $
	Version: 2.99.0.0394 (eagle)

	License:
		This program is free software; you can redistribute it and/or
		modify it under the terms of the GNU General Public License
		as published by the Free Software Foundation; either version 2
		of the License, or (at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program(see GPL.txt); if not, write to the Free Software
		Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

	Note:
		This AddOn's source code is specifically designed to work with
		World of Warcraft's interpreted AddOn system.
		You have an implicit licence to use this AddOn with these facilities
		since that is it's designated purpose as per:
		http://www.fsf.org/licensing/licenses/gpl-faq.html#InterpreterIncompat
]]

GathererLocalizations = {

	daDK = {


		-- Section: Node Category Names
		ORE_ADAMANTITE	= "Adamantit";
		ORE_BLOODSTONE	= "Blodsten";
		ORE_COPPER	= "Kobber";
		ORE_DARKIRON	= "mørk jern";
		ORE_FELIRON	= "Demonisk jern";
		ORE_GOLD	= "guld";
		ORE_INCENDICITE	= "Incendicite";
		ORE_INDURIUM	= "Indurium";
		ORE_IRON	= "jern";
		ORE_KHORIUM	= "Khorium";
		ORE_MITHRIL	= "mithril";
		ORE_OBSIDIAN	= "Obsidian";
		ORE_RADAMANTITE	= "Beriget Adamantit";
		ORE_RTHORIUM	= "Beriget Thorium";
		ORE_SILVER	= "sølv";
		ORE_THORIUM	= "thorium";
		ORE_TIN	= "tin";
		ORE_TRUESILVER	= "Ædelsølv";
		TREASURE_BARREL	= "Tønder";
		TREASURE_BLOODPETAL	= "Blodblomst skud";
		TREASURE_BOX	= "Kasser";
		TREASURE_CASK	= "Fustage";
		TREASURE_CHEST	= "Skatte kiste";
		TREASURE_CLAM	= "Kæmpe muslinger";
		TREASURE_CRATE	= "Kister";
		TREASURE_FOOTLOCKER	= "Skibskiste";
		TREASURE_NIGHTDRAGON	= "Natte Dragens ånde";
		TREASURE_POWERCRYST	= "Kraft krystal";
		TREASURE_SHELLFISHTRAP	= "Krebsdyr fælde";
		TREASURE_SONGFLOWER	= "Sangblomster";
		TREASURE_UNGOROSOIL	= "Un'Goro muld";
		TREASURE_WHIPPERROOT	= "Piskerod knold";
		TREASURE_WINDBLOSSOM	= "Vindblomst bær";


		-- Section: Trade Skill Names
		TRADE_HERBALISM	= "Urter";
		TRADE_MINING	= "Mineraler";

	};

	deDE = {


		-- Section: Node Category Names
		ORE_ADAMANTITE	= "Adamantit";
		ORE_BLOODSTONE	= "Geringes Blutstein";
		ORE_COPPER	= "Kupfer";
		ORE_DARKIRON	= "Dunkeleisen";
		ORE_FELIRON	= "Teufelseisen";
		ORE_GOLD	= "Gold";
		ORE_INCENDICITE	= "Pyrophor";
		ORE_INDURIUM	= "Indurium";
		ORE_IRON	= "Eisen";
		ORE_KHORIUM	= "Khorium";
		ORE_MITHRIL	= "Mithril";
		ORE_OBSIDIAN	= "Obsidian";
		ORE_RADAMANTITE	= "Reiches Adamantit";
		ORE_RTHORIUM	= "Reiches Thorium";
		ORE_SILVER	= "Silber";
		ORE_THORIUM	= "Thorium";
		ORE_TIN	= "Zinn";
		ORE_TRUESILVER	= "Echtsilber";
		TREASURE_BARREL	= "Fass";
		TREASURE_BLOODPETAL	= "Blutblütensprösslinge";
		TREASURE_BOX	= "Kiste";
		TREASURE_CASK	= "Fässlein";
		TREASURE_CHEST	= "Schatztruhe";
		TREASURE_CLAM	= "Riesenmuschel";
		TREASURE_CRATE	= "Kiste";
		TREASURE_FOOTLOCKER	= "Schließkiste";
		TREASURE_GLOWCAP	= "Glühkappe";
		TREASURE_NIGHTDRAGON	= "Nachtdrachenodem";
		TREASURE_POWERCRYST	= "Machtkristall";
		TREASURE_SHELLFISHTRAP	= "Schalentierfalle";
		TREASURE_SONGFLOWER	= "Liedblume";
		TREASURE_UNGOROSOIL	= "Erde von Un'Goro";
		TREASURE_WHIPPERROOT	= "Peitscherwurzelknollen";
		TREASURE_WINDBLOSSOM	= "Windblütenbeeren";


		-- Section: Trade Skill Names
		TRADE_HERBALISM	= "Kräuterkunde";
		TRADE_MINING	= "Bergbau";

	};

	enUS = {


		-- Section: Node Category Names
		ORE_ADAMANTITE	= "Adamantite";
		ORE_BLOODSTONE	= "Lesser Bloodstone";
		ORE_COPPER	= "Copper";
		ORE_DARKIRON	= "Dark Iron";
		ORE_FELIRON	= "Fel Iron";
		ORE_GOLD	= "Gold";
		ORE_INCENDICITE	= "Incendicite";
		ORE_INDURIUM	= "Indurium";
		ORE_IRON	= "Iron";
		ORE_KHORIUM	= "Khorium";
		ORE_MITHRIL	= "Mithril";
		ORE_OBSIDIAN	= "Obsidian";
		ORE_RADAMANTITE	= "Rich Adamantite";
		ORE_RTHORIUM	= "Rich Thorium";
		ORE_SILVER	= "Silver";
		ORE_THORIUM	= "Thorium";
		ORE_TIN	= "Tin";
		ORE_TRUESILVER	= "Truesilver";
		TREASURE_BARREL	= "Barrels";
		TREASURE_BLOODPETAL	= "Bloodpetal Sprouts";
		TREASURE_BOX	= "Boxes";
		TREASURE_CASK	= "Casks";
		TREASURE_CHEST	= "Tresure Chests";
		TREASURE_CLAM	= "Giant Clams";
		TREASURE_CRATE	= "Crates";
		TREASURE_FOOTLOCKER	= "Footlockers";
		TREASURE_GLOWCAP	= "Glowcaps";
		TREASURE_NIGHTDRAGON	= "Night Dragon's Breath";
		TREASURE_POWERCRYST	= "Power Crystals";
		TREASURE_SHELLFISHTRAP	= "Shellfish Traps";
		TREASURE_SONGFLOWER	= "Songflowers";
		TREASURE_UNGOROSOIL	= "Un'Goro Soil";
		TREASURE_WHIPPERROOT	= "Whipper Root Tubers";
		TREASURE_WINDBLOSSOM	= "Windblossom Berries";


		-- Section: Trade Skill Names
		TRADE_HERBALISM	= "Herbalism";
		TRADE_MINING	= "Mining";

	};

	koKR = {


		-- Section: Node Category Names
		ORE_ADAMANTITE	= "아다만타이트";
		ORE_BLOODSTONE	= "저급 혈석";
		ORE_COPPER	= "구리";
		ORE_DARKIRON	= "검은 무쇠";
		ORE_GOLD	= "금";
		ORE_INCENDICITE	= "발연";
		ORE_INDURIUM	= "인듀리움";
		ORE_IRON	= "철";
		ORE_KHORIUM	= "코륨";
		ORE_MITHRIL	= "미스릴";
		ORE_OBSIDIAN	= "흑요석";
		ORE_RADAMANTITE	= "풍부한 아다만타이트";
		ORE_RTHORIUM	= "풍부한 토륨";
		ORE_SILVER	= "은";
		ORE_THORIUM	= "토륨";
		ORE_TIN	= "주석";
		ORE_TRUESILVER	= "진은";
		TREASURE_BARREL	= "배럴";
		TREASURE_BLOODPETAL	= "붉은꽃잎 씨앗";
		TREASURE_BOX	= "상자";
		TREASURE_CASK	= "캐스크";
		TREASURE_CLAM	= "커다란 조개";
		TREASURE_FOOTLOCKER	= "사물함";
		TREASURE_NIGHTDRAGON	= "어둠용의 숨결";
		TREASURE_POWERCRYST	= "마력의 수정";
		TREASURE_SONGFLOWER	= "노래꽃";
		TREASURE_UNGOROSOIL	= "운고로 토양";
		TREASURE_WHIPPERROOT	= "채찍뿌리 줄기";
		TREASURE_WINDBLOSSOM	= "바람꽃 열매";


		-- Section: Trade Skill Names
		TRADE_HERBALISM	= "약초채집";
		TRADE_MINING	= "채광";

	};

	esES = {


		-- Section: Node Category Names
		ORE_COPPER	= "cobre";
		ORE_DARKIRON	= "hierro negro";
		ORE_GOLD	= "oro";
		ORE_IRON	= "hierro";
		ORE_MITHRIL	= "mitril";
		ORE_SILVER	= "plata";
		ORE_THORIUM	= "torio";
		ORE_TIN	= "estaño";
		ORE_TRUESILVER	= "veraplata";

	};

	frFR = {


		-- Section: Node Category Names
		ORE_COPPER	= "cuivre";
		ORE_DARKIRON	= "sombrefer";
		ORE_GOLD	= "or";
		ORE_IRON	= "fer";
		ORE_MITHRIL	= "mithril";
		ORE_SILVER	= "argent";
		ORE_THORIUM	= "thorium";
		ORE_TIN	= "étain";
		ORE_TRUESILVER	= "vrai-argent";


		-- Section: Trade Skill Names
		TRADE_HERBALISM	= "Herboristerie";
		TRADE_MINING	= "Minage";

	};

	itIT = {


		-- Section: Node Category Names
		ORE_COPPER	= "rame";
		ORE_DARKIRON	= "ferro oscuro";
		ORE_GOLD	= "oro";
		ORE_IRON	= "ferro";
		ORE_MITHRIL	= "mithril";
		ORE_SILVER	= "argento";
		ORE_THORIUM	= "thorium";
		ORE_TIN	= "stagno";
		ORE_TRUESILVER	= "argento vero";

	};

	nlNL = {


		-- Section: Node Category Names
		ORE_COPPER	= "koper";
		ORE_DARKIRON	= "duister ijzer";
		ORE_GOLD	= "goud";
		ORE_IRON	= "ijzer";
		ORE_MITHRIL	= "mithril";
		ORE_SILVER	= "zilver";
		ORE_THORIUM	= "thorium";
		ORE_TIN	= "tin";
		ORE_TRUESILVER	= "waarzilver";

	};

	ruRU = {


		-- Section: Node Category Names
		ORE_COPPER	= "Медь";
		ORE_DARKIRON	= "Темное железо";
		ORE_GOLD	= "Золото";
		ORE_IRON	= "Железо";
		ORE_MITHRIL	= "Мифрил";
		ORE_SILVER	= "Серебро";
		ORE_THORIUM	= "Ториум";
		ORE_TIN	= "Бронза";
		ORE_TRUESILVER	= "Истинное Серебро";

	};

	zhCN = {


		-- Section: Node Category Names
		ORE_COPPER	= "铜";
		ORE_DARKIRON	= "黑铁";
		ORE_GOLD	= "金";
		ORE_IRON	= "铁";
		ORE_MITHRIL	= "秘银";
		ORE_SILVER	= "银";
		ORE_THORIUM	= "瑟银";
		ORE_TIN	= "锡";
		ORE_TRUESILVER	= "真银";

	};

	zhTW = {


		-- Section: Node Category Names
		ORE_COPPER	= "銅礦";
		ORE_DARKIRON	= "黑鐵礦";
		ORE_GOLD	= "金礦";
		ORE_IRON	= "鐵礦";
		ORE_MITHRIL	= "秘銀";
		ORE_SILVER	= "銀礦";
		ORE_THORIUM	= "瑟銀";
		ORE_TIN	= "錫礦";
		ORE_TRUESILVER	= "真銀礦";

	};
}
